@@ -22,42 +22,28 @@
 
 #include <gnuradio/rpcserver_booter_aggregator.h>
 
-rpcserver_booter_aggregator::rpcserver_booter_aggregator() :
-  d_type(std::string("aggregator")),
-  server(new rpcserver_aggregator())
-{;}
-
-rpcserver_booter_aggregator::~rpcserver_booter_aggregator()
-{;}
-
-rpcserver_base*
-rpcserver_booter_aggregator::i()
+rpcserver_booter_aggregator::rpcserver_booter_aggregator()
+    : d_type(std::string("aggregator")), server(new rpcserver_aggregator())
 {
-  return &(*server);
+    ;
 }
 
-const std::string&
-rpcserver_booter_aggregator::type()
+rpcserver_booter_aggregator::~rpcserver_booter_aggregator() { ; }
+
+rpcserver_base* rpcserver_booter_aggregator::i() { return &(*server); }
+
+const std::string& rpcserver_booter_aggregator::type() { return d_type; }
+
+const std::vector<std::string> rpcserver_booter_aggregator::endpoints()
 {
-  return d_type;
+    std::vector<std::string> ep;
+    ep.push_back(std::string("TODO"));
+    return ep;
 }
 
-const std::vector<std::string>
-rpcserver_booter_aggregator::endpoints()
+const std::vector<std::string>& rpcserver_booter_aggregator::registeredServers()
 {
-  std::vector<std::string> ep;
-  ep.push_back(std::string("TODO"));
-  return ep;
+    return server->registeredServers();
 }
 
-const std::vector<std::string>&
-rpcserver_booter_aggregator::registeredServers()
-{
-  return server->registeredServers();
-}
-
-rpcserver_aggregator*
-rpcserver_booter_aggregator::agg()
-{
-  return &(*server);
-}
+rpcserver_aggregator* rpcserver_booter_aggregator::agg() { return &(*server); }
