@@ -46,10 +46,8 @@
 
 // helper function to print an ASBD
 
-std::ostream& GR_AUDIO_API
-operator<<
-(std::ostream& s,
- const AudioStreamBasicDescription& asbd);
+std::ostream& GR_AUDIO_API operator<<(std::ostream& s,
+                                      const AudioStreamBasicDescription& asbd);
 
 namespace gr {
 namespace audio {
@@ -58,11 +56,9 @@ namespace osx {
 // returns the number of channels for the provided AudioDeviceID,
 // input and/or output depending on if the pointer is valid.
 
-void GR_AUDIO_API
-get_num_channels_for_audio_device_id
-(AudioDeviceID ad_id,
- UInt32* n_input,
- UInt32* n_output);
+void GR_AUDIO_API get_num_channels_for_audio_device_id(AudioDeviceID ad_id,
+                                                       UInt32* n_input,
+                                                       UInt32* n_output);
 
 // search all known audio devices, input or output, for all that
 // match the provided device_name string (in part or in whole).
@@ -70,12 +66,10 @@ get_num_channels_for_audio_device_id
 // matching names.  If the device name is empty, then match all
 // input or output devices.
 
-void GR_AUDIO_API
-find_audio_devices
-(const std::string& device_name,
- bool is_input,
- std::vector < AudioDeviceID >* all_ad_ids,
- std::vector < std::string >* all_names);
+void GR_AUDIO_API find_audio_devices(const std::string& device_name,
+                                     bool is_input,
+                                     std::vector<AudioDeviceID>* all_ad_ids,
+                                     std::vector<std::string>* all_names);
 
 } /* namespace osx */
 } /* namespace audio */
