@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2011-2018 Free Software Foundation, Inc.
+ * Copyright 2011-2012 Free Software Foundation, Inc.
  *
  * This file is part of GNU Radio
  *
@@ -25,26 +25,26 @@
 #endif
 
 #define _ISOC9X_SOURCE
-#include <float_array_to_int.h>
+#include "float_array_to_int.h"
 #include <math.h>
 #if __cplusplus >= 201103L
 #include <cstdint>
+using std::int64_t;
 #else
 #include <stdint.h>
 #endif
 
-static const int64_t MAX_INT =  INT32_MAX;
-static const int64_t MIN_INT =  INT32_MIN;
+static const int64_t MAX_INT = INT32_MAX;
+static const int64_t MIN_INT = INT32_MIN;
 
-void
-float_array_to_int(const float *in, int *out, float scale, int nsamples)
+void float_array_to_int(const float* in, int* out, float scale, int nsamples)
 {
-  for (int i = 0; i < nsamples; i++){
-    int64_t r = llrintf(scale * in[i]);
-    if (r < MIN_INT)
-      r = MIN_INT;
-    else if (r > MAX_INT)
-      r = MAX_INT;
-    out[i] = static_cast<int>(r);
-  }
+    for (int i = 0; i < nsamples; i++) {
+        int64_t r = llrintf(scale * in[i]);
+        if (r < MIN_INT)
+            r = MIN_INT;
+        else if (r > MAX_INT)
+            r = MAX_INT;
+        out[i] = static_cast<int>(r);
+    }
 }
