@@ -26,23 +26,23 @@
 #include <gnuradio/blocks/nlog10_ff.h>
 
 namespace gr {
-  namespace blocks {
+namespace blocks {
 
-    class BLOCKS_API nlog10_ff_impl : public nlog10_ff
-    {
-      float  d_n;
-      size_t d_vlen;
-      float  d_k;
+class BLOCKS_API nlog10_ff_impl : public nlog10_ff
+{
+    float d_n_log2_10;
+    float d_10_k_n;
+    size_t d_vlen;
 
-    public:
-      nlog10_ff_impl(float n, size_t vlen, float k);
+public:
+    nlog10_ff_impl(float n, size_t vlen, float k);
 
-      int work(int noutput_items,
-	       gr_vector_const_void_star &input_items,
-	       gr_vector_void_star &output_items);
-    };
+    int work(int noutput_items,
+             gr_vector_const_void_star& input_items,
+             gr_vector_void_star& output_items);
+};
 
-  } /* namespace blocks */
+} /* namespace blocks */
 } /* namespace gr */
 
 
