@@ -1,5 +1,5 @@
 /*
- * Copyright 2011 Free Software Foundation, Inc.
+ * Copyright 2011,2019 Free Software Foundation, Inc.
  *
  * This file is part of GNU Radio
  *
@@ -19,15 +19,15 @@
  * Boston, MA 02110-1301, USA.
  */
 
+#include "tag_sink_demo.h"
+#include "tag_source_demo.h"
 #include <gnuradio/top_block.h>
-#include <gnuradio/uhd/usrp_source.h>
 #include <gnuradio/uhd/usrp_sink.h>
-#include <tag_source_demo.h>
-#include <tag_sink_demo.h>
+#include <gnuradio/uhd/usrp_source.h>
 #include <uhd/utils/safe_main.hpp>
 #include <boost/make_shared.hpp>
-#include <boost/thread/thread.hpp> //sleep
 #include <boost/program_options.hpp>
+#include <boost/thread/thread.hpp> //sleep
 #include <csignal>
 #include <iostream>
 
@@ -37,39 +37,51 @@ namespace po = boost::program_options;
  * Signal handlers
  **********************************************************************/
 static bool stop_signal_called = false;
-void sig_int_handler(int){stop_signal_called = true;}
+void sig_int_handler(int) { stop_signal_called = true; }
 
 /***********************************************************************
  * Main w/ program options
  **********************************************************************/
-int UHD_SAFE_MAIN(int argc, char *argv[]){
+int UHD_SAFE_MAIN(int argc, char* argv[])
+{
 
     std::string device_addr, length_tag;
     double center_freq, samp_rate, burst_dur, idle_dur;
 
-    //setup the program options
+    // setup the program options
     po::options_description desc("Allowed options");
-    desc.add_options()
-        ("help", "help message")
-        ("addr", po::value<std::string>(&device_addr)->default_value(""), "the device address in string format")
-        ("rate", po::value<double>(&samp_rate)->default_value(1e6), "the sample rate in samples per second")
-        ("freq", po::value<double>(&center_freq)->default_value(10e6), "the center frequency in Hz")
-        ("burst", po::value<double>(&burst_dur)->default_value(0.1), "the duration of each burst in seconds")
-        ("idle", po::value<double>(&idle_dur)->default_value(0.05), "idle time between bursts in seconds")
-        ("length_tag", po::value<std::string>(&length_tag)->default_value(""), "the length tag key name")
-    ;
+    desc.add_options()("help", "help message")(
+        "addr",
+        po::value<std::string>(&device_addr)->default_value(""),
+        "the device address in string format")(
+        "rate",
+        po::value<double>(&samp_rate)->default_value(1e6),
+        "the sample rate in samples per second")(
+        "freq",
+        po::value<double>(&center_freq)->default_value(10e6),
+        "the center frequency in Hz")("burst",
+                                      po::value<double>(&burst_dur)->default_value(0.1),
+                                      "the duration of each burst in seconds")(
+        "idle",
+        po::value<double>(&idle_dur)->default_value(0.05),
+        "idle time between bursts in seconds")(
+        "length_tag",
+        po::value<std::string>(&length_tag)->default_value(""),
+        "the length tag key name");
     po::variables_map vm;
     po::store(po::parse_command_line(argc, argv, desc), vm);
     po::notify(vm);
 
-    //print the help message
-    if (vm.count("help")){
-        std::cout
-            << boost::format("UHD Tags Demo %s") % desc << std::endl
-            << "The tags sink demo block will print USRP source time stamps." << std::endl
-            << "The tags source demo block will send bursts to the USRP sink." << std::endl
-            << "Look at the USRP output on a scope to see the timed bursts." << std::endl
-            << std::endl;
+    // print the help message
+    if (vm.count("help")) {
+        std::cout << boost::format("UHD Tags Demo %s") % desc << std::endl
+                  << "The tags sink demo block will print USRP source time stamps."
+                  << std::endl
+                  << "The tags source demo block will send bursts to the USRP sink."
+                  << std::endl
+                  << "Look at the USRP output on a scope to see the timed bursts."
+                  << std::endl
+                  << std::endl;
         return ~0;
     }
 
@@ -81,8 +93,8 @@ int UHD_SAFE_MAIN(int argc, char *argv[]){
     //------------------------------------------------------------------
     //-- make the usrp source test blocks
     //------------------------------------------------------------------
-    gr::uhd::usrp_source::sptr usrp_source = gr::uhd::usrp_source::make
-      (device_addr, uhd::stream_args_t("fc32"));
+    gr::uhd::usrp_source::sptr usrp_source =
+        gr::uhd::usrp_source::make(device_addr, uhd::stream_args_t("fc32"));
     usrp_source->set_samp_rate(samp_rate);
     usrp_source->set_center_freq(center_freq);
 
@@ -96,17 +108,20 @@ int UHD_SAFE_MAIN(int argc, char *argv[]){
     //------------------------------------------------------------------
     //-- make the usrp sink test blocks
     //------------------------------------------------------------------
-    gr::uhd::usrp_sink::sptr usrp_sink = gr::uhd::usrp_sink::make
-      (device_addr, uhd::stream_args_t("fc32"), length_tag);
+    gr::uhd::usrp_sink::sptr usrp_sink =
+        gr::uhd::usrp_sink::make(device_addr, uhd::stream_args_t("fc32"), length_tag);
     usrp_sink->set_samp_rate(samp_rate);
     usrp_sink->set_center_freq(center_freq);
     const uhd::time_spec_t time_now = usrp_sink->get_time_now();
     const double actual_samp_rate = usrp_sink->get_samp_rate();
 
     boost::shared_ptr<tag_source_demo> tag_source = boost::make_shared<tag_source_demo>(
-        time_now.get_full_secs() + 1, time_now.get_frac_secs(), //time now + 1 second
-        actual_samp_rate, idle_dur, burst_dur, length_tag
-    );
+        time_now.get_full_secs() + 1,
+        time_now.get_frac_secs(), // time now + 1 second
+        actual_samp_rate,
+        idle_dur,
+        burst_dur,
+        length_tag);
 
     //------------------------------------------------------------------
     //-- connect the usrp sink test blocks
@@ -124,7 +139,7 @@ int UHD_SAFE_MAIN(int argc, char *argv[]){
     //------------------------------------------------------------------
     std::signal(SIGINT, &sig_int_handler);
     std::cout << "press ctrl + c to exit" << std::endl;
-    while (not stop_signal_called){
+    while (not stop_signal_called) {
         boost::this_thread::sleep(boost::posix_time::milliseconds(100));
     }
 
