@@ -23,8 +23,8 @@
 #ifndef INCLUDED_ZEROMQ_PUB_MSG_SINK_IMPL_H
 #define INCLUDED_ZEROMQ_PUB_MSG_SINK_IMPL_H
 
+#include "zmq_common_impl.h"
 #include <gnuradio/zeromq/pub_msg_sink.h>
-#include <zmq.hpp>
 
 namespace gr {
 namespace zeromq {
@@ -37,7 +37,7 @@ private:
     zmq::socket_t* d_socket;
 
 public:
-    pub_msg_sink_impl(char* address, int timeout);
+    pub_msg_sink_impl(char* address, int timeout, bool bind);
     ~pub_msg_sink_impl();
 
     void handler(pmt::pmt_t msg);
