@@ -23,27 +23,34 @@
 #ifndef INCLUDED_ZEROMQ_PUSH_MSG_SINK_IMPL_H
 #define INCLUDED_ZEROMQ_PUSH_MSG_SINK_IMPL_H
 
+#include "zmq_common_impl.h"
 #include <gnuradio/zeromq/push_msg_sink.h>
-#include <zmq.hpp>
 
 namespace gr {
-  namespace zeromq {
+namespace zeromq {
 
-    class push_msg_sink_impl : public push_msg_sink
+class push_msg_sink_impl : public push_msg_sink
+{
+private:
+    float d_timeout;
+    zmq::context_t* d_context;
+    zmq::socket_t* d_socket;
+
+public:
+    push_msg_sink_impl(char* address, int timeout, bool bind);
+    ~push_msg_sink_impl();
+
+    void handler(pmt::pmt_t msg);
+    std::string last_endpoint() override
     {
-    private:
-      float           d_timeout;
-      zmq::context_t  *d_context;
-      zmq::socket_t   *d_socket;
+        char addr[256];
+        size_t addr_len = sizeof(addr);
+        d_socket->getsockopt(ZMQ_LAST_ENDPOINT, addr, &addr_len);
+        return std::string(addr, addr_len - 1);
+    }
+};
 
-    public:
-      push_msg_sink_impl(char *address, int timeout);
-      ~push_msg_sink_impl();
-
-      void handler(pmt::pmt_t msg);
-    };
-
-  } // namespace zeromq
+} // namespace zeromq
 } // namespace gr
 
 #endif /* INCLUDED_ZEROMQ_ZMQ_PUSH_MSG_SINK_IMPL_H */
