@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2013,2014 Free Software Foundation, Inc.
+ * Copyright 2013,2014,2019 Free Software Foundation, Inc.
  *
  * This file is part of GNU Radio.
  *
@@ -23,32 +23,29 @@
 #ifndef INCLUDED_ZEROMQ_REP_SINK_IMPL_H
 #define INCLUDED_ZEROMQ_REP_SINK_IMPL_H
 
+#include "base_impl.h"
 #include <gnuradio/zeromq/rep_sink.h>
-#include <zmq.hpp>
 
 namespace gr {
-  namespace zeromq {
+namespace zeromq {
 
-    class rep_sink_impl : public rep_sink
-    {
-    private:
-      size_t          d_itemsize;
-      size_t          d_vlen;
-      int             d_timeout;
-      zmq::context_t  *d_context;
-      zmq::socket_t   *d_socket;
-      bool            d_pass_tags;
+class rep_sink_impl : public rep_sink, public base_sink_impl
+{
+public:
+    rep_sink_impl(size_t itemsize,
+                  size_t vlen,
+                  char* address,
+                  int timeout,
+                  bool pass_tags,
+                  int hwm);
 
-    public:
-      rep_sink_impl(size_t itemsize, size_t vlen, char *address, int timeout, bool pass_tags);
-      ~rep_sink_impl();
+    int work(int noutput_items,
+             gr_vector_const_void_star& input_items,
+             gr_vector_void_star& output_items);
+    std::string last_endpoint() override { return base_sink_impl::last_endpoint(); }
+};
 
-      int work(int noutput_items,
-               gr_vector_const_void_star &input_items,
-               gr_vector_void_star &output_items);
-    };
-
-  } // namespace zeromq
+} // namespace zeromq
 } // namespace gr
 
 #endif /* INCLUDED_ZEROMQ_REP_SINK_IMPL_H */
