@@ -1,45 +1,50 @@
-#include "qa_utils.h"
-#include <cstring>
-#include <boost/foreach.hpp>
-#include <boost/assign/list_of.hpp>
-#include <boost/tokenizer.hpp>
-#include <boost/xpressive/xpressive.hpp>
-#include <iostream>
-#include <vector>
-#include <list>
-#include <ctime>
-#include <cmath>
-#include <limits>
-#include <boost/lexical_cast.hpp>
 #include <volk/volk.h>
-#include <volk/volk_cpu.h>
-#include <volk/volk_common.h>
-#include <volk/volk_malloc.h>
-#include <boost/typeof/typeof.hpp>
-#include <boost/type_traits.hpp>
-#include <stdio.h>
+#include "qa_utils.h"
 
-float uniform() {
-  return 2.0 * ((float) rand() / RAND_MAX - 0.5);	// uniformly (-1, 1)
-}
+#include <volk/volk.h>                              // for volk_func_desc_t
+#include <volk/volk_malloc.h>                       // for volk_free, volk_m...
 
-template <class t>
-void random_floats (t *buf, unsigned n)
+#include <assert.h>                                 // for assert
+#include <stdint.h>                                 // for uint16_t, uint64_t
+#include <sys/time.h>                               // for CLOCKS_PER_SEC
+#include <sys/types.h>                              // for int16_t, int32_t
+#include <chrono>
+#include <cmath>                                    // for sqrt, fabs, abs
+#include <cstring>                                  // for memcpy, memset
+#include <ctime>                                    // for clock
+#include <fstream>                                  // for operator<<, basic...
+#include <iostream>                                 // for cout, cerr
+#include <limits>                                   // for numeric_limits
+#include <map>                                      // for map, map<>::mappe...
+#include <random>
+#include <vector>                                   // for vector, _Bit_refe...
+
+template <typename T>
+void random_floats(void *buf, unsigned int n, std::default_random_engine& rnd_engine)
 {
-  for (unsigned i = 0; i < n; i++)
-    buf[i] = uniform ();
+    T *array = static_cast<T*>(buf);
+    std::uniform_real_distribution<T> uniform_dist(T(-1), T(1));
+    for(unsigned int i = 0; i < n; i++) {
+        array[i] = uniform_dist(rnd_engine);
+    }
 }
 
 void load_random_data(void *data, volk_type_t type, unsigned int n) {
+    std::random_device rnd_device;
+    std::default_random_engine rnd_engine(rnd_device());
     if(type.is_complex) n *= 2;
     if(type.is_float) {
-        if(type.size == 8) random_floats<double>((double *)data, n);
-        else random_floats<float>((float *)data, n);
+        if(type.size == 8) {
+            random_floats<double>(data, n, rnd_engine);
+        } else {
+            random_floats<float> (data, n, rnd_engine);
+        }
     } else {
         float int_max = float(uint64_t(2) << (type.size*8));
         if(type.is_signed) int_max /= 2.0;
+        std::uniform_real_distribution<float> uniform_dist(-int_max, int_max);
         for(unsigned int i=0; i<n; i++) {
-            float scaled_rand = (((float) (rand() - (RAND_MAX/2))) / static_cast<float>((RAND_MAX/2))) * int_max;
+            float scaled_rand = uniform_dist(rnd_engine);
             //man i really don't know how to do this in a more clever way, you have to cast down at some point
             switch(type.size) {
             case 8:
@@ -51,8 +56,8 @@ void load_random_data(void *data, volk_type_t type, unsigned int n) {
                 else ((uint32_t *)data)[i] = (uint32_t) scaled_rand;
             break;
             case 2:
-                if(type.is_signed) ((int16_t *)data)[i] = (int16_t) scaled_rand;
-                else ((uint16_t *)data)[i] = (uint16_t) scaled_rand;
+                if(type.is_signed) ((int16_t *)data)[i] = (int16_t)((int16_t) scaled_rand % 8);
+                else ((uint16_t *)data)[i] = (uint16_t) ((int16_t) scaled_rand % 8);
             break;
             case 1:
                 if(type.is_signed) ((int8_t *)data)[i] = (int8_t) scaled_rand;
@@ -69,13 +74,28 @@ static std::vector<std::string> get_arch_list(volk_func_desc_t desc) {
     std::vector<std::string> archlist;
 
     for(size_t i = 0; i < desc.n_impls; i++) {
-        //if(!(archs[i+1] & volk_get_lvarch())) continue; //this arch isn't available on this pc
         archlist.push_back(std::string(desc.impl_names[i]));
     }
 
     return archlist;
 }
 
+template <typename T>
+T volk_lexical_cast(const std::string& str)
+{
+    for (unsigned int c_index = 0; c_index < str.size(); ++c_index) {
+        if (str.at(c_index) < '0' || str.at(c_index) > '9') {
+            throw "not all numbers!";
+        }
+    }
+    T var;
+    std::istringstream iss;
+    iss.str(str);
+    iss >> var;
+    // deal with any error bits that may have been set on the stream
+    return var;
+}
+
 volk_type_t volk_type_from_string(std::string name) {
     volk_type_t type;
     type.is_float = false;
@@ -85,7 +105,9 @@ volk_type_t volk_type_from_string(std::string name) {
     type.size = 0;
     type.str = name;
 
-    if(name.size() < 2) throw std::string("name too short to be a datatype");
+    if(name.size() < 2) {
+        throw std::string("name too short to be a datatype");
+    }
 
     //is it a scalar?
     if(name[0] == 's') {
@@ -95,10 +117,11 @@ volk_type_t volk_type_from_string(std::string name) {
 
     //get the data size
     size_t last_size_pos = name.find_last_of("0123456789");
-    if(last_size_pos == std::string::npos)
-      throw std::string("no size spec in type ").append(name);
+    if(last_size_pos == std::string::npos) {
+        throw std::string("no size spec in type ").append(name);
+    }
     //will throw if malformed
-    int size = boost::lexical_cast<int>(name.substr(0, last_size_pos+1));
+    int size = volk_lexical_cast<int>(name.substr(0, last_size_pos+1));
 
     assert(((size % 8) == 0) && (size <= 64) && (size != 0));
     type.size = size/8; //in bytes
@@ -125,14 +148,28 @@ volk_type_t volk_type_from_string(std::string name) {
     return type;
 }
 
+std::vector<std::string> split_signature(const std::string &protokernel_signature) {
+    std::vector<std::string> signature_tokens;
+    std::string token;
+    for (unsigned int loc = 0; loc < protokernel_signature.size(); ++loc) {
+        if (protokernel_signature.at(loc) == '_') {
+            // this is a break
+            signature_tokens.push_back(token);
+            token = "";
+        } else {
+            token.push_back(protokernel_signature.at(loc));
+        }
+    }
+    // Get the last one to the end of the string
+    signature_tokens.push_back(token);
+    return signature_tokens;
+}
+
 static void get_signatures_from_name(std::vector<volk_type_t> &inputsig,
                                    std::vector<volk_type_t> &outputsig,
                                    std::string name) {
-    boost::char_separator<char> sep("_");
-    boost::tokenizer<boost::char_separator<char> > tok(name, sep);
-    std::vector<std::string> toked;
-    tok.assign(name);
-    toked.assign(tok.begin(), tok.end());
+
+    std::vector<std::string> toked = split_signature(name);
 
     assert(toked[0] == "volk");
     toked.erase(toked.begin());
@@ -143,7 +180,8 @@ static void get_signatures_from_name(std::vector<volk_type_t> &inputsig,
     enum { SIDE_INPUT, SIDE_NAME, SIDE_OUTPUT } side = SIDE_INPUT;
     std::string fn_name;
     volk_type_t type;
-    BOOST_FOREACH(std::string token, toked) {
+    for (unsigned int token_index = 0; token_index < toked.size(); ++token_index) {
+        std::string token = toked[token_index];
         try {
             type = volk_type_from_string(token);
             if(side == SIDE_NAME) side = SIDE_OUTPUT; //if this is the first one after the name...
@@ -151,10 +189,10 @@ static void get_signatures_from_name(std::vector<volk_type_t> &inputsig,
             if(side == SIDE_INPUT) inputsig.push_back(type);
             else outputsig.push_back(type);
         } catch (...){
-            if(token[0] == 'x') { //it's a multiplier
+            if(token[0] == 'x' && (token.size() > 1) && (token[1] > '0' || token[1] < '9')) { //it's a multiplier
                 if(side == SIDE_INPUT) assert(inputsig.size() > 0);
                 else assert(outputsig.size() > 0);
-                int multiplier = boost::lexical_cast<int>(token.substr(1, token.size()-1)); //will throw if invalid
+                int multiplier = volk_lexical_cast<int>(token.substr(1, token.size()-1)); //will throw if invalid
                 for(int i=1; i<multiplier; i++) {
                     if(side == SIDE_INPUT) inputsig.push_back(inputsig.back());
                     else outputsig.push_back(outputsig.back());
@@ -215,40 +253,39 @@ inline void run_cast_test3_s32fc(volk_fn_3arg_s32fc func, std::vector<void *> &b
     while(iter--) func(buffs[0], buffs[1], buffs[2], scalar, vlen, arch.c_str());
 }
 
-// This function is a nop that helps resolve GNU Radio bugs 582 and 583.
-// Without this the cast in run_volk_tests for tol_i = static_cast<int>(float tol)
-// won't happen on armhf (reported on cortex A9 and A15).
-void lv_force_cast_hf( int tol_i, float tol_f)
-{
-    int diff_i = 1;
-    float diff_f = 1;
-    if( diff_i > tol_i )
-        std::cout << "" ;
-    if( diff_f > tol_f )
-        std::cout << "" ;
-}
-
 template <class t>
-bool fcompare(t *in1, t *in2, unsigned int vlen, float tol) {
+bool fcompare(t *in1, t *in2, unsigned int vlen, float tol, bool absolute_mode) {
     bool fail = false;
     int print_max_errs = 10;
     for(unsigned int i=0; i<vlen; i++) {
-        // for very small numbers we'll see round off errors due to limited
-        // precision. So a special test case...
-        if(fabs(((t *)(in1))[i]) < 1e-30) {
-            if( fabs( ((t *)(in2))[i] ) > tol )
-            {
+        if (absolute_mode) {
+            if (fabs(((t *)(in1))[i] - ((t *)(in2))[i]) > tol) {
                 fail=true;
                 if(print_max_errs-- > 0) {
-                    std::cout << "offset " << i << " in1: " << t(((t *)(in1))[i]) << " in2: " << t(((t *)(in2))[i]) << std::endl;
+                    std::cout << "offset " << i << " in1: " << t(((t *)(in1))[i]) << " in2: " << t(((t *)(in2))[i]);
+                    std::cout << " tolerance was: " << tol << std::endl;
                 }
             }
-        }
-        // the primary test is the percent different greater than given tol
-        else if(fabs(((t *)(in1))[i] - ((t *)(in2))[i])/(((t *)in1)[i]) > tol) {
-            fail=true;
-            if(print_max_errs-- > 0) {
-                std::cout << "offset " << i << " in1: " << t(((t *)(in1))[i]) << " in2: " << t(((t *)(in2))[i]) << std::endl;
+        } else {
+            // for very small numbers we'll see round off errors due to limited
+            // precision. So a special test case...
+            if(fabs(((t *)(in1))[i]) < 1e-30) {
+                if( fabs( ((t *)(in2))[i] ) > tol )
+                {
+                    fail=true;
+                    if(print_max_errs-- > 0) {
+                    std::cout << "offset " << i << " in1: " << t(((t *)(in1))[i]) << " in2: " << t(((t *)(in2))[i]);
+                        std::cout << " tolerance was: " << tol << std::endl;
+                    }
+                }
+            }
+            // the primary test is the percent different greater than given tol
+            else if(fabs(((t *)(in1))[i] - ((t *)(in2))[i])/fabs(((t *)in1)[i]) > tol) {
+                fail=true;
+                if(print_max_errs-- > 0) {
+                    std::cout << "offset " << i << " in1: " << t(((t *)(in1))[i]) << " in2: " << t(((t *)(in2))[i]);
+                    std::cout << " tolerance was: " << tol << std::endl;
+                }
             }
         }
     }
@@ -257,7 +294,11 @@ bool fcompare(t *in1, t *in2, unsigned int vlen, float tol) {
 }
 
 template <class t>
-bool ccompare(t *in1, t *in2, unsigned int vlen, float tol) {
+bool ccompare(t *in1, t *in2, unsigned int vlen, float tol, bool absolute_mode) {
+    if (absolute_mode) {
+      std::cout << "ccompare does not support absolute mode" << std::endl;
+      return true;
+    }
     bool fail = false;
     int print_max_errs = 10;
     for(unsigned int i=0; i<2*vlen; i+=2) {
@@ -272,7 +313,8 @@ bool ccompare(t *in1, t *in2, unsigned int vlen, float tol) {
             {
                 fail=true;
                 if(print_max_errs-- > 0) {
-                    std::cout << "offset " << i/2 << " in1: " << in1[i] << " + " << in1[i+1] << "j  in2: " << in2[i] << " + " << in2[i+1] << "j" << std::endl;
+                    std::cout << "offset " << i/2 << " in1: " << in1[i] << " + " << in1[i+1] << "j  in2: " << in2[i] << " + " << in2[i+1] << "j";
+                    std::cout << " tolerance was: " << tol << std::endl;
                 }
             }
         }
@@ -280,7 +322,8 @@ bool ccompare(t *in1, t *in2, unsigned int vlen, float tol) {
         else if((err / norm) > tol) {
             fail=true;
             if(print_max_errs-- > 0) {
-                std::cout << "offset " << i/2 << " in1: " << in1[i] << " + " << in1[i+1] << "j  in2: " << in2[i] << " + " << in2[i+1] << "j" << std::endl;
+                std::cout << "offset " << i/2 << " in1: " << in1[i] << " + " << in1[i+1] << "j  in2: " << in2[i] << " + " << in2[i+1] << "j";
+                std::cout << " tolerance was: " << tol << std::endl;
             }
         }
     }
@@ -289,14 +332,19 @@ bool ccompare(t *in1, t *in2, unsigned int vlen, float tol) {
 }
 
 template <class t>
-bool icompare(t *in1, t *in2, unsigned int vlen, unsigned int tol) {
+bool icompare(t *in1, t *in2, unsigned int vlen, unsigned int tol, bool absolute_mode) {
+    if (absolute_mode) {
+      std::cout << "icompare does not support absolute mode" << std::endl;
+      return true;
+    }
     bool fail = false;
     int print_max_errs = 10;
     for(unsigned int i=0; i<vlen; i++) {
-        if(abs(int(((t *)(in1))[i]) - int(((t *)(in2))[i])) > tol) {
+      if(((unsigned int)abs(int(((t *)(in1))[i]) - int(((t *)(in2))[i]))) > tol) {
             fail=true;
             if(print_max_errs-- > 0) {
-                std::cout << "offset " << i << " in1: " << static_cast<int>(t(((t *)(in1))[i])) << " in2: " << static_cast<int>(t(((t *)(in2))[i])) << std::endl;
+                std::cout << "offset " << i << " in1: " << static_cast<int>(t(((t *)(in1))[i])) << " in2: " << static_cast<int>(t(((t *)(in2))[i]));
+                std::cout << " tolerance was: " << tol << std::endl;
             }
         }
     }
@@ -321,34 +369,46 @@ public:
 private: std::vector<void * > _mems;
 };
 
+bool run_volk_tests(volk_func_desc_t desc,
+                    void (*manual_func)(),
+                    std::string name,
+                    volk_test_params_t test_params,
+                    std::vector<volk_test_results_t> *results,
+                    std::string puppet_master_name
+)
+{
+    return run_volk_tests(desc, manual_func, name, test_params.tol(), test_params.scalar(),
+        test_params.vlen(), test_params.iter(), results, puppet_master_name,
+        test_params.absolute_mode(), test_params.benchmark_mode());
+}
+
 bool run_volk_tests(volk_func_desc_t desc,
                     void (*manual_func)(),
                     std::string name,
                     float tol,
                     lv_32fc_t scalar,
-                    int vlen,
-                    int iter,
-                    std::vector<std::string> *best_arch_vector = 0,
-                    std::string puppet_master_name = "NULL",
-                    bool benchmark_mode,
-                    std::string kernel_regex
-                   ) {
-    boost::xpressive::sregex kernel_expression = boost::xpressive::sregex::compile(kernel_regex);
-    if( !boost::xpressive::regex_search(name, kernel_expression) ) {
-        // in this case we have a regex and are only looking to test one kernel
-        return false;
-    }
+                    unsigned int vlen,
+                    unsigned int iter,
+                    std::vector<volk_test_results_t> *results,
+                    std::string puppet_master_name,
+                    bool absolute_mode,
+                    bool benchmark_mode
+) {
+    // Initialize this entry in results vector
+    results->push_back(volk_test_results_t());
+    results->back().name = name;
+    results->back().vlen = vlen;
+    results->back().iter = iter;
     std::cout << "RUN_VOLK_TESTS: " << name << "(" << vlen << "," << iter << ")" << std::endl;
 
-    // The multiply and lv_force_cast_hf are work arounds for GNU Radio bugs 582 and 583
-    // The bug is the casting/assignment below do not happen, which results in false
-    // positives when testing for errors in fcompare and icompare.
-    // Since this only happens on armhf (reported for Cortex A9 and A15) combined with
-    // the following fixes it is suspected to be a compiler bug.
-    // Bug 1272024 on launchpad has been filed with Linaro GCC.
-    const float tol_f = tol*1.0000001;
+    // vlen_twiddle will increase vlen for malloc and data generation
+    // but kernels will still be called with the user provided vlen.
+    // This is useful for causing errors in kernels that do bad reads
+    const unsigned int vlen_twiddle = 5;
+    vlen = vlen + vlen_twiddle;
+
+    const float tol_f = tol;
     const unsigned int tol_i = static_cast<const unsigned int>(tol);
-    lv_force_cast_hf( tol_i, tol_f );
 
     //first let's get a list of available architectures for the test
     std::vector<std::string> arch_list = get_arch_list(desc);
@@ -363,7 +423,14 @@ bool run_volk_tests(volk_func_desc_t desc,
 
     //now we have to get a function signature by parsing the name
     std::vector<volk_type_t> inputsig, outputsig;
-    get_signatures_from_name(inputsig, outputsig, name);
+    try {
+        get_signatures_from_name(inputsig, outputsig, name);
+    }
+    catch (std::exception &error) {
+        std::cerr << "Error: unable to get function signature from kernel name" << std::endl;
+        std::cerr << "  - " << name << std::endl;
+        return false;
+    }
 
     //pull the input scalars into their own vector
     std::vector<volk_type_t> inputsc;
@@ -374,10 +441,9 @@ bool run_volk_tests(volk_func_desc_t desc,
             i -= 1;
         }
     }
-    //for(int i=0; i<inputsig.size(); i++) std::cout << "Input: " << inputsig[i].str << std::endl;
-    //for(int i=0; i<outputsig.size(); i++) std::cout << "Output: " << outputsig[i].str << std::endl;
     std::vector<void *> inbuffs;
-    BOOST_FOREACH(volk_type_t sig, inputsig) {
+    for (unsigned int inputsig_index = 0; inputsig_index < inputsig.size(); ++ inputsig_index) {
+        volk_type_t sig = inputsig[inputsig_index];
         if(!sig.is_scalar) //we don't make buffers for scalars
           inbuffs.push_back(mem_pool.get_new(vlen*sig.size*(sig.is_complex ? 2 : 1)));
     }
@@ -393,7 +459,9 @@ bool run_volk_tests(volk_func_desc_t desc,
             arch_buffs.push_back(mem_pool.get_new(vlen*outputsig[j].size*(outputsig[j].is_complex ? 2 : 1)));
         }
         for(size_t j=0; j<inputsig.size(); j++) {
-            arch_buffs.push_back(inbuffs[j]);
+            void *arch_inbuff = mem_pool.get_new(vlen*inputsig[j].size*(inputsig[j].is_complex ? 2 : 1));
+            memcpy(arch_inbuff, inbuffs[j], vlen * inputsig[j].size * (inputsig[j].is_complex ? 2 : 1));
+            arch_buffs.push_back(arch_inbuff);
         }
         test_data.push_back(arch_buffs);
     }
@@ -403,10 +471,11 @@ bool run_volk_tests(volk_func_desc_t desc,
     both_sigs.insert(both_sigs.end(), inputsig.begin(), inputsig.end());
 
     //now run the test
-    clock_t start, end;
+    vlen = vlen - vlen_twiddle;
+    std::chrono::time_point<std::chrono::system_clock> start, end;
     std::vector<double> profile_times;
     for(size_t i = 0; i < arch_list.size(); i++) {
-        start = clock();
+        start = std::chrono::system_clock::now();
 
         switch(both_sigs.size()) {
             case 1:
@@ -450,9 +519,16 @@ bool run_volk_tests(volk_func_desc_t desc,
                 break;
         }
 
-        end = clock();
-        double arch_time = 1000.0 * (double)(end-start)/(double)CLOCKS_PER_SEC;
-        std::cout << arch_list[i] << " completed in " << arch_time << "ms" << std::endl;
+        end = std::chrono::system_clock::now();
+        std::chrono::duration<double> elapsed_seconds = end - start;
+        double arch_time = 1000.0 * elapsed_seconds.count();
+        std::cout << arch_list[i] << " completed in " << arch_time << " ms" << std::endl;
+        volk_test_time_t result;
+        result.name = arch_list[i];
+        result.time = arch_time;
+        result.units = "ms";
+        result.pass = true;
+        results->back().results[result.name] = result;
 
         profile_times.push_back(arch_time);
     }
@@ -460,13 +536,15 @@ bool run_volk_tests(volk_func_desc_t desc,
     //and now compare each output to the generic output
     //first we have to know which output is the generic one, they aren't in order...
     size_t generic_offset=0;
-    for(size_t i=0; i<arch_list.size(); i++)
-        if(arch_list[i] == "generic") generic_offset=i;
+    for(size_t i=0; i<arch_list.size(); i++) {
+        if (arch_list[i] == "generic") {
+            generic_offset = i;
+        }
+    }
 
-    //now compare
-    //if(outputsig.size() == 0) outputsig = inputsig; //a hack, i know
-
-    bool fail = false;
+    // Just in case a kernel wrote to OOB memory, use the twiddled vlen
+    vlen = vlen + vlen_twiddle;
+    bool fail;
     bool fail_global = false;
     std::vector<bool> arch_results;
     for(size_t i=0; i<arch_list.size(); i++) {
@@ -476,16 +554,15 @@ bool run_volk_tests(volk_func_desc_t desc,
                 if(both_sigs[j].is_float) {
                     if(both_sigs[j].size == 8) {
                         if (both_sigs[j].is_complex) {
-                            fail = ccompare((double *) test_data[generic_offset][j], (double *) test_data[i][j], vlen, tol_f);
-
+                            fail = ccompare((double *) test_data[generic_offset][j], (double *) test_data[i][j], vlen, tol_f, absolute_mode);
                         } else {
-                            fail = fcompare((double *) test_data[generic_offset][j], (double *) test_data[i][j], vlen, tol_f);
+                            fail = fcompare((double *) test_data[generic_offset][j], (double *) test_data[i][j], vlen, tol_f, absolute_mode);
                         }
                     } else {
                         if (both_sigs[j].is_complex) {
-                            fail = ccompare((float *) test_data[generic_offset][j], (float *) test_data[i][j], vlen, tol_f);
+                            fail = ccompare((float *) test_data[generic_offset][j], (float *) test_data[i][j], vlen, tol_f, absolute_mode);
                         } else {
-                            fail = fcompare((float *) test_data[generic_offset][j], (float *) test_data[i][j], vlen, tol_f);
+                            fail = fcompare((float *) test_data[generic_offset][j], (float *) test_data[i][j], vlen, tol_f, absolute_mode);
                         }
                     }
                 } else {
@@ -493,30 +570,41 @@ bool run_volk_tests(volk_func_desc_t desc,
                     switch(both_sigs[j].size) {
                     case 8:
                         if(both_sigs[j].is_signed) {
-                            fail = icompare((int64_t *) test_data[generic_offset][j], (int64_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i);
+                            fail = icompare((int64_t *) test_data[generic_offset][j], (int64_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i, absolute_mode);
                         } else {
-                            fail = icompare((uint64_t *) test_data[generic_offset][j], (uint64_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i);
+                            fail = icompare((uint64_t *) test_data[generic_offset][j], (uint64_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i, absolute_mode);
                         }
                         break;
                     case 4:
-                        if(both_sigs[j].is_signed) {
-                            fail = icompare((int32_t *) test_data[generic_offset][j], (int32_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i);
-                        } else {
-                            fail = icompare((uint32_t *) test_data[generic_offset][j], (uint32_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i);
+                        if(both_sigs[j].is_complex) {
+                            if(both_sigs[j].is_signed) {
+                                fail = icompare((int16_t *) test_data[generic_offset][j], (int16_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i, absolute_mode);
+                            } else {
+                                fail = icompare((uint16_t *) test_data[generic_offset][j], (uint16_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i, absolute_mode);
+                            }
+                        }
+                        else {
+                            if (both_sigs[j].is_signed) {
+                                fail = icompare((int32_t *) test_data[generic_offset][j], (int32_t *) test_data[i][j],
+                                                vlen * (both_sigs[j].is_complex ? 2 : 1), tol_i, absolute_mode);
+                            } else {
+                                fail = icompare((uint32_t *) test_data[generic_offset][j], (uint32_t *) test_data[i][j],
+                                                vlen * (both_sigs[j].is_complex ? 2 : 1), tol_i, absolute_mode);
+                            }
                         }
                         break;
                     case 2:
                         if(both_sigs[j].is_signed) {
-                            fail = icompare((int16_t *) test_data[generic_offset][j], (int16_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i);
+                            fail = icompare((int16_t *) test_data[generic_offset][j], (int16_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i, absolute_mode);
                         } else {
-                            fail = icompare((uint16_t *) test_data[generic_offset][j], (uint16_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i);
+                            fail = icompare((uint16_t *) test_data[generic_offset][j], (uint16_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i, absolute_mode);
                         }
                         break;
                     case 1:
                         if(both_sigs[j].is_signed) {
-                            fail = icompare((int8_t *) test_data[generic_offset][j], (int8_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i);
+                            fail = icompare((int8_t *) test_data[generic_offset][j], (int8_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i, absolute_mode);
                         } else {
-                            fail = icompare((uint8_t *) test_data[generic_offset][j], (uint8_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i);
+                            fail = icompare((uint8_t *) test_data[generic_offset][j], (uint8_t *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_i, absolute_mode);
                         }
                         break;
                     default:
@@ -524,10 +612,11 @@ bool run_volk_tests(volk_func_desc_t desc,
                     }
                 }
                 if(fail) {
+                    volk_test_time_t *result = &results->back().results[arch_list[i]];
+                    result->pass = !fail;
                     fail_global = true;
                     std::cout << name << ": fail on arch " << arch_list[i] << std::endl;
                 }
-                //fail = memcmp(outbuffs[generic_offset], outbuffs[i], outputsig[0].size * vlen * (outputsig[0].is_complex ? 2:1));
             }
         }
         arch_results.push_back(!fail);
@@ -553,16 +642,14 @@ bool run_volk_tests(volk_func_desc_t desc,
 
     std::cout << "Best aligned arch: " << best_arch_a << std::endl;
     std::cout << "Best unaligned arch: " << best_arch_u << std::endl;
-    if(best_arch_vector) {
-        if(puppet_master_name == "NULL") {
-            best_arch_vector->push_back(name + " " + best_arch_a + " " + best_arch_u);
-        }
-        else {
-            best_arch_vector->push_back(puppet_master_name + " " + best_arch_a + " " + best_arch_u);
-        }
+
+    if(puppet_master_name == "NULL") {
+        results->back().config_name = name;
+    } else {
+        results->back().config_name = puppet_master_name;
     }
+    results->back().best_arch_a = best_arch_a;
+    results->back().best_arch_u = best_arch_u;
 
     return fail_global;
 }
-
-
